==> openshift-client-4.6.2-sources.jar: io/fabric8/openshift/client/dsl/internal/ImageOperationsImpl.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

              

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.DoneableImage;
import io.fabric8.openshift.api.model.Image;
import io.fabric8.openshift.api.model.ImageList;
import io.fabric8.openshift.api.model.DoneableImage;

import java.util.Map;
import java.util.TreeMap;


public class ImageOperationsImpl extends OpenShiftOperation<Image, ImageList, DoneableImage, Resource<Image, DoneableImage>> {

  public ImageOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config));
  }

  public ImageOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("image.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("images"));
    this.type = Image.class;
    this.listType = ImageList.class;
    this.doneableType = DoneableImage.class;
  }

  public ImageOperationsImpl newInstance(OperationContext context) {
    return new ImageOperationsImpl(context);
  }
}

==> openshift-client-4.10.0-sources.jar: io/fabric8/openshift/client/dsl/internal/ImageOperationsImpl.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.DoneableImage;
import io.fabric8.openshift.api.model.Image;
import io.fabric8.openshift.api.model.ImageList;
import io.fabric8.openshift.api.model.DoneableImage;

import java.util.Map;
import java.util.TreeMap;


public class ImageOperationsImpl extends OpenShiftOperation<Image, ImageList, DoneableImage, Resource<Image, DoneableImage>> {

  public ImageOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ImageOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("image.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("images"));
    this.type = Image.class;
    this.listType = ImageList.class;
    this.doneableType = DoneableImage.class;
  }

  public ImageOperationsImpl newInstance(OperationContext context) {
    return new ImageOperationsImpl(context);
  }
}
